@@ -5,6 +5,7 @@ import polars as pl
 from cameo_claw.net import requests_get
 
 import warnings
+import pandas as pd
 
 warnings.filterwarnings("ignore")
 
@@ -37,8 +38,15 @@ def write_gzip(bytesio, path):
 
 
 def read_csv_distinct(bytes1, lst_distinct_column):
-    print('119')
-    df = pl.read_csv(bytes1, infer_schema_length=20000)
+    print('119', len(bytes1))
+    print(bytes1[0:10])
+    print('119.1')
+    # df = pl.read_csv(bytes1, infer_schema_length=20000)
+    print('119.2')
+    df_pandas = pd.read_csv(BytesIO(bytes1), compression='gzip')
+    print('119.3')
+    df = pl.from_pandas(df_pandas)
+    print('119.4')
     print('120')
     df = df.distinct(subset=lst_distinct_column)
     print('121')
